==> cxf-testutils-2.0.6.13-fuse-sources.jar: org/apache/type_test/types1/RecSeqB6918.java <==

package org.apache.type_test.types1;

import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlElements;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for RecSeqB6918 complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="RecSeqB6918">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence maxOccurs="unbounded" minOccurs="0">
 *         &lt;element name="nextSeq" type="{http://apache.org/type_test/types1}RecSeqB6918" minOccurs="0"/>
 *         &lt;element name="varInt" type="{http://www.w3.org/2001/XMLSchema}int"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "RecSeqB6918", propOrder = {
    "nextSeqAndVarInt"
})
public class RecSeqB6918 {

    @XmlElements({
        @XmlElement(name = "varInt", namespace = "http://apache.org/type_test/types1", required = true, type = Integer.class),
        @XmlElement(name = "nextSeq", namespace = "http://apache.org/type_test/types1", required = true, type = RecSeqB6918 .class)
    })
    protected List<Object> nextSeqAndVarInt;

    /**
     * Gets the value of the nextSeqAndVarInt property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the nextSeqAndVarInt property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getNextSeqAndVarInt().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link Integer }
     * {@link RecSeqB6918 }
     * 
     * 
     */
    public List<Object> getNextSeqAndVarInt() {
        if (nextSeqAndVarInt == null) {
            nextSeqAndVarInt = new ArrayList<Object>();
        }
        return this.nextSeqAndVarInt;
    }

}

==> cxf-testutils-2.0.10.1-fuse-sources.jar: org/apache/type_test/types1/RecSeqB6918.java <==

package org.apache.type_test.types1;

import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlElements;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for RecSeqB6918 complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="RecSeqB6918">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence maxOccurs="unbounded" minOccurs="0">
 *         &lt;element name="nextSeq" type="{http://apache.org/type_test/types1}RecSeqB6918" minOccurs="0"/>
 *         &lt;element name="varInt" type="{http://www.w3.org/2001/XMLSchema}int"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "RecSeqB6918", propOrder = {
    "nextSeqAndVarInt"
})
public class RecSeqB6918 {

    @XmlElements({
        @XmlElement(name = "nextSeq", namespace = "http://apache.org/type_test/types1", required = true, type = RecSeqB6918 .class),
        @XmlElement(name = "varInt", namespace = "http://apache.org/type_test/types1", required = true, type = Integer.class)
    })
    protected List<Object> nextSeqAndVarInt;

    /**
     * Gets the value of the nextSeqAndVarInt property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the nextSeqAndVarInt property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getNextSeqAndVarInt().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link RecSeqB6918 }
     * {@link Integer }
     * 
     * 
     */
    public List<Object> getNextSeqAndVarInt() {
        if (nextSeqAndVarInt == null) {
            nextSeqAndVarInt = new ArrayList<Object>();
        }
        return this.nextSeqAndVarInt;
    }

}
